"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const backfill_cache_1 = require("backfill-cache");
const logger_1 = require("../logger");
class RemoteFallbackCacheProvider {
    constructor(cacheOptions, logger, cwd) {
        this.cacheOptions = cacheOptions;
        this.localCacheStorageProvider = backfill_cache_1.getCacheStorageProvider({
            provider: "local",
        }, cacheOptions.internalCacheFolder, logger, cwd);
        // Remote providers should have a provider name of something other than "local" OR it is
        // a custom provider (currently S3 would be a custom provider)
        const isRemoteProvider = backfill_cache_1.isCustomProvider(cacheOptions.cacheStorageConfig) ||
            (typeof cacheOptions.cacheStorageConfig.provider === "string" &&
                !cacheOptions.cacheStorageConfig.provider.includes("local"));
        if (isRemoteProvider) {
            logger.silly("remote provider enabled");
            this.remoteCacheStorageProvider = backfill_cache_1.getCacheStorageProvider(cacheOptions.cacheStorageConfig, cacheOptions.internalCacheFolder, logger, cwd);
        }
    }
    async fetch(hash) {
        logger_1.logger.silly(`local cache fetch: ${hash}`);
        const hit = await this.localCacheStorageProvider.fetch(hash);
        if (!hit && this.remoteCacheStorageProvider) {
            logger_1.logger.silly(`remote fallback fetch: ${hash}`);
            return await this.remoteCacheStorageProvider.fetch(hash);
        }
        return hit;
    }
    async put(hash, filesToCache) {
        logger_1.logger.silly(`local cache put: ${hash}`);
        const localPut = this.localCacheStorageProvider.put(hash, filesToCache);
        const shouldWriteRemoteCache = !!this.remoteCacheStorageProvider && this.cacheOptions.writeRemoteCache;
        if (shouldWriteRemoteCache) {
            logger_1.logger.silly(`remote fallback put: ${hash}`);
            const remotePut = this.remoteCacheStorageProvider.put(hash, filesToCache);
            await Promise.all([localPut, remotePut]);
        }
        else {
            await localPut;
        }
    }
}
exports.RemoteFallbackCacheProvider = RemoteFallbackCacheProvider;
